@@ -768,6 +768,67 @@ int get_feat_info_max1617a( updates *node, sensors_chip_name name, int num ) {
     return SUCCESS;
 }
 
+#define SMSC47B397_NUM_FEAT 8
+                
+/* Get the feature info for smsc47b397 sensor. */
+int get_feat_info_smsc47b397( updates *node, sensors_chip_name name, int num ) {
+    switch (num) {
+        case 1:
+            node->featnum = SENSORS_SMSC47B397_TEMP1;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = TEMP;
+            break;
+        case 2:
+            node->featnum = SENSORS_SMSC47B397_TEMP2;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = TEMP;
+            break;
+        case 3:
+            node->featnum = SENSORS_SMSC47B397_TEMP3;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = TEMP;
+            break;
+        case 4:
+            node->featnum = SENSORS_SMSC47B397_TEMP4;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = TEMP;
+            break;
+        case 5:
+            node->featnum = SENSORS_SMSC47B397_FAN1;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 6:
+            node->featnum = SENSORS_SMSC47B397_FAN2;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 7:
+            node->featnum = SENSORS_SMSC47B397_FAN3;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 8:
+            node->featnum = SENSORS_SMSC47B397_FAN4;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        default:
+            return FAILURE;
+    }
+
+    return SUCCESS;
+}
+
+
 #define VIA686A_NUM_FEAT 10
                 
 /* Get the feature info for via686a sensor. */
@@ -1235,6 +1296,8 @@ int get_num_feat( sensors_chip_name name ) {
         return EEPROM_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_IT87_PREFIX ) == 0 ) {
         return IT87_NUM_FEAT;
+    } else if ( strcmp( name.prefix, SENSORS_IT8712_PREFIX ) == 0 ) {
+        return IT87_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_LM75_PREFIX ) == 0 ) {
         return LM75_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_LM78_PREFIX ) == 0 ) {
@@ -1262,6 +1325,8 @@ int get_num_feat( sensors_chip_name name ) {
         return MAX1617_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_MAX1617A_PREFIX ) == 0 ) {
         return MAX1617A_NUM_FEAT;
+    } else if ( strcmp( name.prefix, SENSORS_SMSC47B397_PREFIX ) == 0 ) {
+        return SMSC47B397_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_VIA686A_PREFIX ) == 0 ) {
         return VIA686A_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_W83781D_PREFIX ) == 0 ) {
@@ -1301,6 +1366,8 @@ updates *add_node( updates *node, sensors_chip_name name, GtkWidget *darea,
         retval = get_feat_info_eeprom( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_IT87_PREFIX ) == 0 ) {
         retval = get_feat_info_it87( node, name, num );
+    } else if ( strcmp( name.prefix, SENSORS_IT8712_PREFIX ) == 0 ) {
+        retval = get_feat_info_it87( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_LM75_PREFIX ) == 0 ) {
         retval = get_feat_info_lm75( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_LM78_PREFIX ) == 0 ) {
@@ -1328,6 +1395,8 @@ updates *add_node( updates *node, sensors_chip_name name, GtkWidget *darea,
         retval = get_feat_info_max1617( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_MAX1617A_PREFIX ) == 0 ) {
         retval = get_feat_info_max1617a( node, name, num );
+    } else if ( strcmp( name.prefix, SENSORS_SMSC47B397_PREFIX ) == 0 ) {
+        retval = get_feat_info_smsc47b397( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_VIA686A_PREFIX ) == 0 ) {
         retval = get_feat_info_via686a( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_W83781D_PREFIX ) == 0 ) {
