@@ -332,6 +332,19 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                                      widget->style->fg_gc[ GTK_WIDGET_STATE
                                      (widget) ], theme, 54, 150,
                                      161, 0, 75, 30 );
+                } else if ( current->curvalue == 8 ) {
+                    gdk_draw_drawable( widget->window,
+                                     widget->style->fg_gc[ GTK_WIDGET_STATE
+                                     (widget) ], theme, 55, 120,
+                                     0, 0, 57, 30 );
+                    gdk_draw_drawable( widget->window,
+                                     widget->style->fg_gc[ GTK_WIDGET_STATE
+                                     (widget) ], theme, 36, 0,
+                                     57, 0, 18, 30 );
+                    gdk_draw_drawable( widget->window,
+                                     widget->style->fg_gc[ GTK_WIDGET_STATE
+                                     (widget) ], theme, 112, 120,
+                                     75, 0, 104, 30 );
                 } else {
                     gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
@@ -403,7 +416,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             } else {
                 sensors_get_feature( current->name, SENSORS_EEPROM_TYPE, 
                                      &tempD );
-                if ( tempD == 4.0 || tempD == 7.0 ) {
+                if ( tempD == 4.0 || tempD == 7.0 || tempD == 8.0 ) {
                     sensors_get_feature(current->name, SENSORS_EEPROM_ROWADDR, 
                                         &a);
                     sensors_get_feature(current->name, SENSORS_EEPROM_COLADDR, 
@@ -414,8 +427,14 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                                         &d);
                     result = (((int) a) & 0x0f) + (((int) b) & 0x0f) - 17;
 
-                    if(result > 0 && result <= 12 && c <= 8 && d <= 8)
+                    if ( tempD == 8.0 ) { /* DDR2 */
+                        result = (1 << result) * ((((int) c) & 0x07) + 1)
+                                 * ((int) d);
+
+                    } else if ( result > 0 && result <= 12 && c <= 8 && d <= 8 )
+                    {
                         result = (1 << result) * ((int) c) * ((int) d);
+                    }
                 }
            
                 gdk_draw_drawable( widget->window, 
@@ -442,13 +461,11 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                                  (widget) ], theme, x, highLow, 
                                  54, 0, 18, 30 );
                     
-                if ( result >= 100 ) {
+                if ( result >= 100 || x != 198 ) {
                     curInt = result / 100;
                     result = result % 100;
             
                     get_pm_location( curInt, &x );
-                } else {
-                    x = 198;
                 }
             
                 gdk_draw_drawable( widget->window, 
@@ -456,13 +473,11 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                                  (widget) ], theme, x, highLow, 
                                  72, 0, 18, 30 );
 
-                if ( result >= 10 ) {
+                if ( result >= 10 || x != 198 ) {
                     curInt = result / 10;
                     result = result % 10;
             
                     get_pm_location( curInt, &x );
-                } else {
-                    x = 198;
                 }
             
                 gdk_draw_drawable( widget->window, 
@@ -506,12 +521,9 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
 /* Free the link list. */
 gint free_llist( updates *node ) {
 
-    if ( node->next == NULL ) {
-        g_free( node );
-    } else {
+    if ( node != NULL ) {
         free_llist( node->next );
-        node->next = NULL;
-        free_llist( node );
+        g_free( node );
     }
 
     return SUCCESS;
